# Stochastic Covariance Regularization

## imagenet.py

This file is for training models with various loss functions on the ImageNet dataset.
Code from [here](https://github.com/pytorch/examples/tree/main/imagenet) is adapted 
to be used with loss functions defined in this repository.

A "loss" option is included to the adapted code. Run ```python imagenet.py --help```
for a proper description.
